[![Docker](https://github.com/contextmachine/mmcore/actions/workflows/docker-publish.yml/badge.svg)](https://github.com/contextmachine/mmcore/actions/workflows/docker-publish.yml)
[![Build documentation](https://github.com/contextmachine/mmcore/actions/workflows/build-docs.yml/badge.svg)](https://github.com/contextmachine/mmcore/actions/workflows/build-docs.yml)
[![poetry-build](https://github.com/contextmachine/mmcore/actions/workflows/poetry-build.yml/badge.svg)](https://github.com/contextmachine/mmcore/actions/workflows/poetry-build.yml)
# mmcore


## Base Docker Image
Pull image
```bash
docker pull ghcr.io/contextmachine/mmcore:latest
```
Using in Dockerfile
```dockerfile
FROM ghcr.io/contextmachine/mmcore:latest
```
## Install with pip
```bash
python -m pip install git+https://github.com/contextmachine/mmcore.git
```

---
